@@ -4,7 +4,7 @@ from mindsdb_sql.utils import indent
 
 class Set(ASTNode):
     def __init__(self,
-                 category,
+                 category=None,
                  arg=None,
                  *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -24,5 +24,5 @@ class Set(ASTNode):
 
     def get_string(self, *args, **kwargs):
         arg_str = f' {str(self.arg)}' if self.arg else ''
-        return f'SET {self.category}{arg_str}'
+        return f'SET {self.category if self.category else ""}{arg_str}'
 
