@@ -11,6 +11,8 @@ as a string.
 class MindsDBLexer(Lexer):
     reflags = re.IGNORECASE
     ignore = ' \t\n\r'
+    ignore_multi_comment = r'/\*.*?\*/'
+    ignore_line_comment = r'--[^\n]*'
 
     tokens = {
         USE, DROP, CREATE, DESCRIBE, RETRAIN,
@@ -20,8 +22,8 @@ class MindsDBLexer(Lexer):
 
         # Mindsdb special
 
-        PREDICTOR, PREDICTORS, DATASOURCE, INTEGRATION, INTEGRATIONS,
-        STREAM, STREAMS, PUBLICATION, PUBLICATIONS, VIEW, VIEWS,
+        PREDICTOR, PREDICTORS, DATASOURCE, INTEGRATION, INTEGRATIONS,DATASOURCES,
+        STREAM, STREAMS, PUBLICATION, PUBLICATIONS, VIEW, VIEWS, DATASETS,
 
         LATEST, HORIZON, USING,
         ENGINE, TRAIN, TEST, PREDICT, MODEL, PARAMETERS,
@@ -83,8 +85,10 @@ class MindsDBLexer(Lexer):
     DATASOURCE = r'\bDATASOURCE\b'
     INTEGRATION = r'\bINTEGRATION\b'
     INTEGRATIONS = r'\bINTEGRATIONS\b'
+    DATASOURCES = r'\bDATASOURCES\b'
     PUBLICATION = r'\bPUBLICATION\b'
     PUBLICATIONS = r'\bPUBLICATIONS\b'
+    DATASETS = r'\bDATASETS\b'
     LATEST = r'\bLATEST\b'
 
     # Misc
